==> humhub-1.3.1.tar.gz: humhub-1.3.1/protected/humhub/modules/content/messages/nl/richtexteditor.php <==
<?php
return array (
  'Activity' => 'Activiteit',
  'Add or remove link' => 'Hyperlink toevoegen of verwijderen',
  'Animals & Nature' => 'Dieren en natuur',
  'Change to code block' => 'Verander naar codeblok',
  'Change to heading' => 'Verander naar kop',
  'Change to paragraph' => 'Verander naar paragraaf',
  'Code' => 'Code',
  'Columns' => 'Kolommen',
  'Create a link' => 'Maak een hyperlink',
  'Create table' => 'Maak een tabel',
  'Delete column' => 'Kolom verwijderen',
  'Delete row' => 'Rij verwijderen',
  'Delete table' => 'Tabel verwijderen',
  'Flags' => 'Vlaggen',
  'Food & Drink' => 'Eten & drinken',
  'Height' => 'Hoogte',
  'Horizontal rule' => 'Horizontale lijn',
  'Image' => 'Afbeelding',
  'Insert' => 'Invoegen',
  'Insert column after' => 'Kolom invoegen na',
  'Insert column before' => 'Kolom invoegen voor',
  'Insert horizontal rule' => 'Horizontale lijn invoegen',
  'Insert image' => 'Afbeeldingen invoegen',
  'Insert row after' => 'Rij invoegen na',
  'Insert row before' => 'Rij invoegen voor',
  'Insert table' => 'Tabel invoegen',
  'Link target' => 'Link doel',
  'Location' => 'Plaats',
  'Objects' => 'Objecten',
  'Paragraph' => 'Paragraaf',
  'People' => 'Mensen',
  'Rows' => 'Rijen',
  'Symbols' => 'Symbolen',
  'Title' => 'Titel',
  'Toggle code font' => 'Code',
  'Toggle emphasis' => 'Vet',
  'Toggle strikethrough' => 'Doorhalen',
  'Toggle strong style' => 'Cursief',
  'Travel & Places' => 'Reizen & plaatsen',
  'Type' => 'Type',
  'Upload File' => 'Upload bestand',
  'Upload and include a File' => 'Upload en voeg een bestand toe',
  'Width' => 'Breedte',
  'Wrap in block quote' => 'Maak een blokcitaat',
  'Wrap in bullet list' => 'Maak een lijst met opsomtekens',
  'Wrap in ordered list' => 'Naak een genummerde lijst',
);

==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/content/messages/nl/richtexteditor.php <==
<?php
return array (
  'Activity' => 'Activiteit',
  'Add or remove link' => 'Hyperlink toevoegen of verwijderen',
  'Animals & Nature' => 'Dieren en natuur',
  'Change to code block' => 'Verander naar codeblok',
  'Change to heading' => 'Verander naar kop',
  'Change to paragraph' => 'Verander naar paragraaf',
  'Code' => 'Code',
  'Columns' => 'Kolommen',
  'Create a link' => 'Maak een hyperlink',
  'Create table' => 'Maak een tabel',
  'Delete column' => 'Kolom verwijderen',
  'Delete row' => 'Rij verwijderen',
  'Delete table' => 'Tabel verwijderen',
  'Flags' => 'Vlaggen',
  'Food & Drink' => 'Eten & drinken',
  'Height' => 'Hoogte',
  'Horizontal rule' => 'Horizontale lijn',
  'Image' => 'Afbeelding',
  'Insert' => 'Invoegen',
  'Insert column after' => 'Kolom invoegen na',
  'Insert column before' => 'Kolom invoegen voor',
  'Insert horizontal rule' => 'Horizontale lijn invoegen',
  'Insert image' => 'Afbeeldingen invoegen',
  'Insert row after' => 'Rij invoegen na',
  'Insert row before' => 'Rij invoegen voor',
  'Insert table' => 'Tabel invoegen',
  'Link target' => 'Hyperlink doel',
  'Location' => 'Plaats',
  'Objects' => 'Objecten',
  'Paragraph' => 'Paragraaf',
  'People' => 'Mensen',
  'Rows' => 'Rijen',
  'Symbols' => 'Symbolen',
  'Title' => 'Titel',
  'Toggle code font' => 'Code',
  'Toggle emphasis' => 'Cursief',
  'Toggle strikethrough' => 'Doorhalen',
  'Toggle strong style' => 'Vet',
  'Travel & Places' => 'Reizen & plaatsen',
  'Type' => 'Type',
  'Upload File' => 'Upload bestand',
  'Upload and include a File' => 'Upload en voeg een bestand toe',
  'Width' => 'Breedte',
  'Wrap in block quote' => 'Maak een blokcitaat',
  'Wrap in bullet list' => 'Maak een lijst met opsomtekens',
  'Wrap in ordered list' => 'Maak een genummerde lijst',
);
